null_to_na <- function (x) {

    if (length (x) == 0) {
        x <- NA
    }
    return (x)
}
